@@ -3,7 +3,8 @@ from quickcsv.file import *
 from collections import OrderedDict
 import os
 
-def divide_by_tag(meta_csv_file,raw_text_folder,output_folder,list_category, start_year=2010,end_year=2021, tag_field="tag",keyword_field="keyword",year_field='year',time_field="time",id_field="Id",prefix_filename=""):
+def divide_by_tag(meta_csv_file,raw_text_folder,output_folder,list_category, start_year=2010,end_year=2021, tag_field="tag",keyword_field="keyword",
+                  year_field='year',time_field="time",id_field="Id",prefix_filename="",skip_date=False):
 
     if not os.path.exists(output_folder):
         os.mkdir(output_folder)
@@ -40,8 +41,9 @@ def divide_by_tag(meta_csv_file,raw_text_folder,output_folder,list_category, sta
             "Keyword": keyword
         }
         # print(model)
-        if year == "":
-            continue
+        if not skip_date:
+            if year == "":
+                continue
 
         text_path = f"{raw_text_folder}/{prefix_filename}{Id}.txt"
         if not os.path.exists(text_path):
