@@ -1,16 +1,9 @@
 import os
-import os
 from gensim import corpora, models
 import gensim
 import re
-from quickcsv.file import *
 import jieba
 import jieba.posseg as pseg
-from nltk.tokenize import word_tokenize
-import string
-from nltk.corpus import stopwords
-from nltk.stem.porter import PorterStemmer
-from nltk.stem import WordNetLemmatizer
 from gensim.utils import lemmatize, simple_preprocess
 import spacy
 import pandas as pd
