@@ -1,9 +1,4 @@
-from gensim import corpora, models
-import gensim
-import jieba
-import jieba.posseg as pseg
-from quickcsv.file import *
-import os
+from gensim import  models
 from quick_topic.topic_interaction.lda_by_tag_each import *
 
 def build_lda_model(list_doc,num_topics=6,num_words=50,num_pass=5,list_term_file=None,stopwords_path="",save_name="topic",output_folder="output",lang='zh',
