@@ -1,6 +1,5 @@
 import numpy as np
 from collections import OrderedDict
-from strsimpy.metric_lcs import MetricLCS
 import os
 from quickcsv.file import *
 # topic files
@@ -81,28 +80,6 @@ def get_cosine_sim_by_dicts(dict1,dict2):
 
 
 def estimate_topic_similarity(list_topic,topic_folder,list_keywords_file="",topN=30,lang='zh',result_path=''):
-
-
-    # carbon keywords
-    #carbon2_keywords = [w.strip() for w in open(list_keywords_file, 'r', encoding='utf-8').readlines()
-    #                    if w.strip() != ""]
-    '''
-    print("Results: ")
-    dict_topic = {}
-    print("Topic\tSub-Topic\tTotalWeight\tMainKeywords")
-    for idx, topic in enumerate(list_topic):
-        for sub_topic in list_sub_topic[idx]:
-            topic_weight, _, top_keywords, top_keywords_weights, dict_kw = load_topic_file(carbon2_keywords,output_folder,topic, sub_topic,
-                                                                                                      top=topN)
-            # print(topic_weight)
-            # print(list_topic_w)
-            # print(top_keywords)
-            ks = ",".join(top_keywords)
-            line = f"{topic}\t{sub_topic}\t{topic_weight}\t{ks}"
-            dict_topic[f"{topic}-{sub_topic}"] = dict_kw
-            print(line)
-    '''
-
     print()
     list_item=[]
     print("Category-Pair\tTopic-Similarity")
