@@ -1,17 +1,13 @@
 import pickle
-import sys
 import re, numpy as np, pandas as pd
 from pprint import pprint
 import os
-import jieba
 import jieba.posseg as pseg
-# Gensim
 import gensim, spacy, logging, warnings
 import gensim.corpora as corpora
 from gensim.utils import lemmatize, simple_preprocess
 from gensim.models import CoherenceModel
-import matplotlib.pyplot as plt
-import  matplotlib
+import matplotlib
 from matplotlib import pyplot as plt
 from wordcloud import WordCloud
 import matplotlib.colors as mcolors
